.. _recipe_asr.berry:

asr.berry
=========


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.berry`-recipe.
This recipe is comprised of 2 steps, namely:

  - :py:func:`asr.berry.calculate`
  - :py:func:`asr.berry.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.berry

or as a python module

.. code-block:: console

   $ python -m asr.berry

Detailed description
--------------------
Topological analysis of electronic structure.

Steps
-----


asr.berry@calculate
^^^^^^^^^^^^^^^^^^^
.. autofunction:: asr.berry.calculate
   

asr.berry
^^^^^^^^^
.. autofunction:: asr.berry.main
   